pub trait HttpRequest {
type Stream: HttpStream;
type Error: From<Error> + Into<<Self::Stream as HttpStream>::Error>;
// Required methods
fn apply_headers(
&mut self,
boundary: &str,
content_len: Option<u64>,
) -> bool;
fn open_stream(self) -> Result<Self::Stream, Self::Error>;
}Expand description
A trait describing an HTTP request that can be used to send multipart data.
Required Associated Types
Sourcetype Stream: HttpStream
type Stream: HttpStream
The HTTP stream type that can be opend by this request, to which the multipart data will be written.
Required Methods
Sourcefn apply_headers(&mut self, boundary: &str, content_len: Option<u64>) -> bool
fn apply_headers(&mut self, boundary: &str, content_len: Option<u64>) -> bool
Set the Content-Type header to multipart/form-data and supply the boundary value.
If content_len is given, set the Content-Length header to its value.
Return true if any and all sanity checks passed and the stream is ready to be opened,
or false otherwise.
Sourcefn open_stream(self) -> Result<Self::Stream, Self::Error>
fn open_stream(self) -> Result<Self::Stream, Self::Error>
Open the request stream and return it or any error otherwise.
Implementations on Foreign Types
Sourceimpl HttpRequest for ()
impl HttpRequest for ()
Implementors
Sourceimpl HttpRequest for ClientRequest
Available on crate feature client only.
impl HttpRequest for ClientRequest
Available on crate feature
client only.